package apis

import (
    "fmt"

	"github.com/gin-gonic/gin"
	"github.com/go-admin-team/go-admin-core/sdk/api"
	"github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth/user"
	_ "github.com/go-admin-team/go-admin-core/sdk/pkg/response"

	"go-admin/app/operate/models"
	"go-admin/app/operate/service"
	"go-admin/app/operate/service/dto"
	"go-admin/common/actions"
)

type OrgClubUser struct {
	api.Api
}

// GetPage 获取俱乐部账户信息列表
// @Summary 获取俱乐部账户信息列表
// @Description 获取俱乐部账户信息列表
// @Tags 俱乐部账户信息
// @Param pageSize query int false "页条数"
// @Param pageIndex query int false "页码"
// @Success 200 {string} string  "{"code": 200, "data": [...]}"
// @Router /api/v1/org-club-user [get]
// @Security Bearer
func (e OrgClubUser) GetPage(c *gin.Context) {
    req := dto.OrgClubUserGetPageReq{}
    s := service.OrgClubUser{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
   	if err != nil {
   		e.Logger.Error(err)
   		e.Error(500, err, err.Error())
   		return
   	}

	p := actions.GetPermissionFromContext(c)
	list := make([]models.OrgClubUser, 0)
	var count int64

	err = s.GetPage(&req, p, &list, &count)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("获取俱乐部账户信息 失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.PageOK(list, int(count), req.GetPageIndex(), req.GetPageSize(), "查询成功")
}

// Get 获取俱乐部账户信息
// @Summary 获取俱乐部账户信息
// @Description 获取俱乐部账户信息
// @Tags 俱乐部账户信息
// @Param id path string false "id"
// @Success 200 {string} string  {data=models.OrgClubUser} "{"code": 200, "data": [...]}"
// @Router /api/v1/org-club-user/{id} [get]
// @Security Bearer
func (e OrgClubUser) Get(c *gin.Context) {
	req := dto.OrgClubUserGetReq{}
	s := service.OrgClubUser{}
    err := e.MakeContext(c).
		MakeOrm().
		Bind(&req).
		MakeService(&s.Service).
		Errors
	if err != nil {
		e.Logger.Error(err)
		e.Error(500, err, err.Error())
		return
	}
	var object models.OrgClubUser

	p := actions.GetPermissionFromContext(c)
	err = s.Get(&req, p, &object)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("获取俱乐部账户信息失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.OK( object, "查询成功")
}

// Insert 创建俱乐部账户信息
// @Summary 创建俱乐部账户信息
// @Description 创建俱乐部账户信息
// @Tags 俱乐部账户信息
// @Accept application/json
// @Product application/json
// @Param data body dto.OrgClubUserInsertReq true "data"
// @Success 200 {string} string  	"{"code": 200, "message": "添加成功"}"
// @Router /api/v1/org-club-user [post]
// @Security Bearer
func (e OrgClubUser) Insert(c *gin.Context) {
    req := dto.OrgClubUserInsertReq{}
    s := service.OrgClubUser{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }
	// 设置创建人
	req.SetCreateBy(user.GetUserId(c))

	err = s.Insert(&req)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("创建俱乐部账户信息  失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.OK(req.GetId(), "创建成功")
}

// Update 修改俱乐部账户信息
// @Summary 修改俱乐部账户信息
// @Description 修改俱乐部账户信息
// @Tags 俱乐部账户信息
// @Accept application/json
// @Product application/json
// @Param data body dto.OrgClubUserUpdateReq true "body"
// @Success 200 {string} string  	"{"code": 200, "message": "修改成功"}"
// @Router /api/v1/org-club-user/{id} [put]
// @Security Bearer
func (e OrgClubUser) Update(c *gin.Context) {
    req := dto.OrgClubUserUpdateReq{}
    s := service.OrgClubUser{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }
	req.SetUpdateBy(user.GetUserId(c))
	p := actions.GetPermissionFromContext(c)

	err = s.Update(&req, p)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("修改俱乐部账户信息 失败，\r\n失败信息 %s", err.Error()))
        return
	}
	e.OK( req.GetId(), "修改成功")
}

// Delete 删除俱乐部账户信息
// @Summary 删除俱乐部账户信息
// @Description 删除俱乐部账户信息
// @Tags 俱乐部账户信息
// @Param ids body []int false "ids"
// @Success 200 {string} string  	"{"code": 200, "message": "删除成功"}"
// @Router /api/v1/org-club-user [delete]
// @Security Bearer
func (e OrgClubUser) Delete(c *gin.Context) {
    s := service.OrgClubUser{}
    req := dto.OrgClubUserDeleteReq{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }

	// req.SetUpdateBy(user.GetUserId(c))
	p := actions.GetPermissionFromContext(c)

	err = s.Remove(&req, p)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("删除俱乐部账户信息失败，\r\n失败信息 %s", err.Error()))
        return
	}
	e.OK( req.GetId(), "删除成功")
}