package dto

import (
	"go-admin/app/operate/models"
	"go-admin/common/dto"
	common "go-admin/common/models"
	"time"
)

type OrgLeagueGetPageReq struct {
	dto.Pagination `search:"-"`
	LeagueName     string `form:"leagueName"  search:"type:contains;column:league_name;table:org_league" comment:"联赛级别"` //联赛级别
}

type OrgLeagueOrder struct {
	Id         int       `form:"idOrder"  search:"type:order;column:id;table:org_league"`
	LeagueName string    `form:"leagueNameOrder"  search:"type:order;column:league_name;table:org_league"`
	Status     string    `form:"statusOrder"  search:"type:order;column:status;table:org_league"`
	CreateBy   string    `form:"createByOrder"  search:"type:order;column:create_by;table:org_league"`
	UpdateBy   string    `form:"updateByOrder"  search:"type:order;column:update_by;table:org_league"`
	CreatedAt  time.Time `form:"createdAtOrder"  search:"type:order;column:created_at;table:org_league"`
	UpdatedAt  time.Time `form:"updatedAtOrder"  search:"type:order;column:updated_at;table:org_league"`
	DeletedAt  time.Time `form:"deletedAtOrder"  search:"type:order;column:deleted_at;table:org_league"`
}

func (m *OrgLeagueGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type OrgLeagueInsertReq struct {
	Id         int    `json:"-" comment:""` //
	LeagueName string `json:"leagueName" comment:"联赛级别"`
	Status     string `json:"status" comment:"联赛开启状态 1 是 0 否"`
	common.ControlBy
}

func (s *OrgLeagueInsertReq) Generate(model *models.OrgLeague) {
	if s.Id == 0 {
		model.Model = common.Model{Id: s.Id}
	}
	model.LeagueName = s.LeagueName
	model.Status = s.Status
}

func (s *OrgLeagueInsertReq) GetId() interface{} {
	return s.Id
}

type OrgLeagueUpdateReq struct {
	Id         int    `uri:"id" comment:""` //
	LeagueName string `json:"leagueName" comment:"联赛级别"`
	Status     string `json:"status" comment:"联赛开启状态 1 是 0 否"`
	common.ControlBy
}

func (s *OrgLeagueUpdateReq) Generate(model *models.OrgLeague) {
	if s.Id == 0 {
		model.Model = common.Model{Id: s.Id}
	}
	model.LeagueName = s.LeagueName
	model.Status = s.Status
}

func (s *OrgLeagueUpdateReq) GetId() interface{} {
	return s.Id
}

// OrgLeagueGetReq 功能获取请求参数
type OrgLeagueGetReq struct {
	Id int `uri:"id"`
}

func (s *OrgLeagueGetReq) GetId() interface{} {
	return s.Id
}

// OrgLeagueDeleteReq 功能删除请求参数
type OrgLeagueDeleteReq struct {
	Ids []int `json:"ids"`
}

func (s *OrgLeagueDeleteReq) GetId() interface{} {
	return s.Ids
}
