package service

import (
	"errors"

	"github.com/go-admin-team/go-admin-core/sdk/service"
	"gorm.io/gorm"

	"go-admin/app/operate/models"
	"go-admin/app/operate/service/dto"
	"go-admin/common/actions"
	cDto "go-admin/common/dto"
)

type OrgDivision struct {
	service.Service
}

// GetPage 获取OrgDivision列表
func (e *OrgDivision) GetPage(c *dto.OrgDivisionGetPageReq, p *actions.DataPermission, list *[]models.OrgDivision, count *int64) error {
	var err error
	var data models.OrgDivision

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("OrgDivisionService GetPage error:%s \r\n", err)
		return err
	}
	return nil
}

// Get 获取OrgDivision对象
func (e *OrgDivision) Get(d *dto.OrgDivisionGetReq, p *actions.DataPermission, model *models.OrgDivision) error {
	var data models.OrgDivision

	err := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).
		First(model, d.GetId()).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetOrgDivision error:%s \r\n", err)
		return err
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err
	}
	return nil
}

// Insert 创建OrgDivision对象
func (e *OrgDivision) Insert(c *dto.OrgDivisionInsertReq) error {
	var err error
	var data models.OrgDivision
	c.Generate(&data)
	err = e.Orm.Create(&data).Error
	if err != nil {
		e.Log.Errorf("OrgDivisionService Insert error:%s \r\n", err)
		return err
	}
	return nil
}

// Update 修改OrgDivision对象
func (e *OrgDivision) Update(c *dto.OrgDivisionUpdateReq, p *actions.DataPermission) error {
	var err error
	var data = models.OrgDivision{}
	e.Orm.Scopes(
		actions.Permission(data.TableName(), p),
	).First(&data, c.GetId())
	c.Generate(&data)

	db := e.Orm.Updates(&data)
	if db.Error != nil {
		e.Log.Errorf("OrgDivisionService Save error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权更新该数据")
	}
	return nil
}

// Remove 删除OrgDivision
func (e *OrgDivision) Remove(d *dto.OrgDivisionDeleteReq, p *actions.DataPermission) error {
	var data models.OrgDivision

	db := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).Delete(&data, d.GetId())
	if err := db.Error; err != nil {
		e.Log.Errorf("Service RemoveOrgDivision error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权删除该数据")
	}
	return nil
}
