package service

import (
	"errors"

	"github.com/go-admin-team/go-admin-core/sdk/service"
	"gorm.io/gorm"

	"go-admin/app/operate/models"
	"go-admin/app/operate/service/dto"
	"go-admin/common/actions"
	cDto "go-admin/common/dto"
)

type OrgNews struct {
	service.Service
}

// GetPage 获取OrgNews列表
func (e *OrgNews) GetPage(c *dto.OrgNewsGetPageReq, p *actions.DataPermission, list *[]models.OrgNews, count *int64) error {
	var err error
	var data models.OrgNews

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("OrgNewsService GetPage error:%s \r\n", err)
		return err
	}
	return nil
}

// Get 获取OrgNews对象
func (e *OrgNews) Get(d *dto.OrgNewsGetReq, p *actions.DataPermission, model *models.OrgNews) error {
	var data models.OrgNews

	err := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).
		First(model, d.GetId()).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetOrgNews error:%s \r\n", err)
		return err
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err
	}
	return nil
}

// Insert 创建OrgNews对象
func (e *OrgNews) Insert(c *dto.OrgNewsInsertReq) error {
	var err error
	var data models.OrgNews
	c.Generate(&data)
	err = e.Orm.Create(&data).Error
	if err != nil {
		e.Log.Errorf("OrgNewsService Insert error:%s \r\n", err)
		return err
	}
	return nil
}

// Update 修改OrgNews对象
func (e *OrgNews) Update(c *dto.OrgNewsUpdateReq, p *actions.DataPermission) error {
	var err error
	var data = models.OrgNews{}
	e.Orm.Scopes(
		actions.Permission(data.TableName(), p),
	).First(&data, c.GetId())
	c.Generate(&data)

	db := e.Orm.Updates(&data)
	if db.Error != nil {
		e.Log.Errorf("OrgNewsService Save error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权更新该数据")
	}
	return nil
}

// Remove 删除OrgNews
func (e *OrgNews) Remove(d *dto.OrgNewsDeleteReq, p *actions.DataPermission) error {
	var data models.OrgNews

	db := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).Delete(&data, d.GetId())
	if err := db.Error; err != nil {
		e.Log.Errorf("Service RemoveOrgNews error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权删除该数据")
	}
	return nil
}
