package service

import (
	"errors"

	"github.com/go-admin-team/go-admin-core/sdk/service"
	"gorm.io/gorm"

	"go-admin/app/operate/models"
	"go-admin/app/operate/service/dto"
	"go-admin/common/actions"
	cDto "go-admin/common/dto"
)

type OrgPlayerUser struct {
	service.Service
}

// GetPage 获取OrgPlayerUser列表
func (e *OrgPlayerUser) GetPage(c *dto.OrgPlayerUserGetPageReq, p *actions.DataPermission, list *[]models.OrgPlayerUser, count *int64) error {
	var err error
	var data models.OrgPlayerUser

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("OrgPlayerUserService GetPage error:%s \r\n", err)
		return err
	}
	return nil
}

// Get 获取OrgPlayerUser对象
func (e *OrgPlayerUser) Get(d *dto.OrgPlayerUserGetReq, p *actions.DataPermission, model *models.OrgPlayerUser) error {
	var data models.OrgPlayerUser

	err := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).
		First(model, d.GetId()).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetOrgPlayerUser error:%s \r\n", err)
		return err
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err
	}
	return nil
}

// Insert 创建OrgPlayerUser对象
func (e *OrgPlayerUser) Insert(c *dto.OrgPlayerUserInsertReq) error {
	var err error
	var data models.OrgPlayerUser
	c.Generate(&data)
	err = e.Orm.Create(&data).Error
	if err != nil {
		e.Log.Errorf("OrgPlayerUserService Insert error:%s \r\n", err)
		return err
	}
	c.Id = data.Id
	return nil
}

// Update 修改OrgPlayerUser对象
func (e *OrgPlayerUser) Update(c *dto.OrgPlayerUserUpdateReq, p *actions.DataPermission) error {
	var err error
	var data = models.OrgPlayerUser{}
	e.Orm.Scopes(
		actions.Permission(data.TableName(), p),
	).First(&data, c.GetId())
	c.Generate(&data)

	db := e.Orm.Updates(&data)
	if db.Error != nil {
		e.Log.Errorf("OrgPlayerUserService Save error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权更新该数据")
	}
	return nil
}

// Remove 删除OrgPlayerUser
func (e *OrgPlayerUser) Remove(d *dto.OrgPlayerUserDeleteReq, p *actions.DataPermission) error {
	var data models.OrgPlayerUser

	db := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).Delete(&data, d.GetId())
	if err := db.Error; err != nil {
		e.Log.Errorf("Service RemoveOrgPlayerUser error:%s \r\n", err)
		return err
	}
	if db.RowsAffected == 0 {
		return errors.New("无权删除该数据")
	}
	return nil
}

func (e *OrgPlayerUser) IsBeing(username string) (error, int) {
	var data models.OrgPlayerUser

	err := e.Orm.Model(&data).
		Where("username=?", username).
		First(&data).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetOrgMatchTeamPlayer error:%s \r\n", err)
		return err, 0
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err, 0
	}
	return nil, data.Id
}
